FmonRunner class
Top-level orchestrator: wires the process/connection, file watcher, debouncer and reloader together, and drives them from file events and keyboard input.
Constructors
- FmonRunner(FmonConfig config)
Properties
- config → FmonConfig
-
final
- console → Console
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- notifier → Notifier
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
) → Future< int> -
Runs until interrupted (Ctrl-C or
q). Returns the process exit code. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited